Index: inc/calendar.hxx
===================================================================
RCS file: /cvs/util/svtools/inc/calendar.hxx,v
retrieving revision 1.5
retrieving revision 1.5.82.1
diff -u -r1.5 -r1.5.82.1
--- inc/calendar.hxx	21 Dec 2005 17:54:12 -0000	1.5
+++ inc/calendar.hxx	22 Feb 2006 12:00:18 -0000	1.5.82.1
@@ -200,7 +200,7 @@
 	Rectangle		maPrevRect;
 	Rectangle		maNextRect;
 	String			maDayOfWeekText;
-	long			mnDayOfWeekAry[7];
+	sal_Int32		mnDayOfWeekAry[7];
 	Date			maOldFormatFirstDate;
 	Date			maOldFormatLastDate;
 	Date			maFirstDate;
Index: inc/gifread.hxx
===================================================================
RCS file: /cvs/util/svtools/inc/gifread.hxx,v
retrieving revision 1.3
retrieving revision 1.3.176.1
diff -u -r1.3 -r1.3.176.1
--- inc/gifread.hxx	8 Sep 2005 09:34:06 -0000	1.3
+++ inc/gifread.hxx	22 Feb 2006 12:02:07 -0000	1.3.176.1
@@ -94,8 +94,8 @@
 	BitmapWriteAccess*	pAcc1;
 	long				nYAcc;
 	long				nLastPos;
-	ULONG				nLogWidth100;
-	ULONG				nLogHeight100;
+	sal_uInt32			nLogWidth100;
+	sal_uInt32			nLogHeight100;
 	USHORT				nTimer;
 	USHORT				nGlobalWidth;			// maximale Bildbreite aus Header
 	USHORT				nGlobalHeight;			// maximale Bildhoehe aus Header
Index: inc/roadmap.hxx
===================================================================
RCS file: /cvs/util/svtools/inc/roadmap.hxx,v
retrieving revision 1.6
retrieving revision 1.6.178.1
diff -u -r1.6 -r1.6.178.1
--- inc/roadmap.hxx	8 Sep 2005 10:12:14 -0000	1.6
+++ inc/roadmap.hxx	22 Feb 2006 12:00:18 -0000	1.6.178.1
@@ -170,7 +170,7 @@
 
 
     protected:
-        sal_Int32       PreNotify( NotifyEvent& rNEvt );
+        long       		PreNotify( NotifyEvent& rNEvt );
 
     protected:
         /// called when an item has been selected by any means
Index: source/control/roadmap.cxx
===================================================================
RCS file: /cvs/util/svtools/source/control/roadmap.cxx,v
retrieving revision 1.9
retrieving revision 1.9.178.1
diff -u -r1.9 -r1.9.178.1
--- source/control/roadmap.cxx	8 Sep 2005 15:04:54 -0000	1.9
+++ source/control/roadmap.cxx	22 Feb 2006 12:00:18 -0000	1.9.178.1
@@ -663,7 +663,7 @@
     }
 
 	//---------------------------------------------------------------------
-    sal_Int32 ORoadmap::PreNotify( NotifyEvent& _rNEvt )
+    long ORoadmap::PreNotify( NotifyEvent& _rNEvt )
     {
         // capture KeyEvents for taskpane cycling
         if ( _rNEvt.GetType() == EVENT_KEYINPUT )
Index: source/filerec/filerec.cxx
===================================================================
RCS file: /cvs/util/svtools/source/filerec/filerec.cxx,v
retrieving revision 1.5
retrieving revision 1.5.178.1
diff -u -r1.5 -r1.5.178.1
--- source/filerec/filerec.cxx	8 Sep 2005 15:31:57 -0000	1.5
+++ source/filerec/filerec.cxx	22 Feb 2006 12:02:07 -0000	1.5.178.1
@@ -230,7 +230,7 @@
 
 {
 	// die ersten 4 Bytes als Mini-Header lesen
-	ULONG nHeader;
+	sal_uInt32 nHeader;
 	*pStream >> nHeader;
 
 	// k"onnte es sich um einen extended-Record handeln?
@@ -836,7 +836,7 @@
 		*_pStream << _nContentCount;
 		if ( SFX_REC_TYPE_VARSIZE_RELOC == _nPreTag ||
 			 SFX_REC_TYPE_MIXTAGS_RELOC == _nPreTag )
-			*_pStream << nContentOfsPos - ( _pStream->Tell() + sizeof(UINT32) );
+			*_pStream << static_cast<UINT32>(nContentOfsPos - ( _pStream->Tell() + sizeof(UINT32) ));
 		else
 			*_pStream << nContentOfsPos;
 
Index: source/filter.vcl/wmf/emfwr.cxx
===================================================================
RCS file: /cvs/util/svtools/source/filter.vcl/wmf/emfwr.cxx,v
retrieving revision 1.14
retrieving revision 1.14.152.1
diff -u -r1.14 -r1.14.152.1
--- source/filter.vcl/wmf/emfwr.cxx	5 Oct 2005 13:20:44 -0000	1.14
+++ source/filter.vcl/wmf/emfwr.cxx	22 Feb 2006 12:02:07 -0000	1.14.152.1
@@ -251,7 +251,7 @@
 
 // -----------------------------------------------------------------------------
 
-void EMFWriter::ImplBeginRecord( ULONG nType )
+void EMFWriter::ImplBeginRecord( sal_uInt32 nType )
 {
 	DBG_ASSERT( !mbRecordOpen, "Another record is already opened!" );
 
@@ -290,7 +290,7 @@
 
 // -----------------------------------------------------------------------------
 
-BOOL EMFWriter::ImplPrepareHandleSelect( ULONG& rHandle, ULONG nSelectType )
+BOOL EMFWriter::ImplPrepareHandleSelect( sal_uInt32& rHandle, ULONG nSelectType )
 {
 	if( rHandle != HANDLE_INVALID )
 	{
@@ -328,8 +328,8 @@
 {
 	if( mbLineChanged && ImplPrepareHandleSelect( mnLineHandle, LINE_SELECT ) )
 	{
-		ULONG nStyle = maVDev.IsLineColor() ? 0 : 5;
-		ULONG nWidth = 0, nHeight = 0;
+		sal_uInt32 nStyle = maVDev.IsLineColor() ? 0 : 5;
+		sal_uInt32 nWidth = 0, nHeight = 0;
 
 		ImplBeginRecord( WIN_EMR_CREATEPEN );
 		(*mpStm) << mnLineHandle << nStyle << nWidth << nHeight;
@@ -348,8 +348,8 @@
 {
 	if( mbFillChanged && ImplPrepareHandleSelect( mnFillHandle, FILL_SELECT ) )
 	{
-		ULONG nStyle = maVDev.IsFillColor() ? 0 : 1;
-		ULONG nPatternStyle = 0;
+		sal_uInt32 nStyle = maVDev.IsFillColor() ? 0 : 1;
+		sal_uInt32 nPatternStyle = 0;
 
 		ImplBeginRecord( WIN_EMR_CREATEBRUSHINDIRECT );
 		(*mpStm) << mnFillHandle << nStyle;
Index: source/filter.vcl/wmf/emfwr.hxx
===================================================================
RCS file: /cvs/util/svtools/source/filter.vcl/wmf/emfwr.hxx,v
retrieving revision 1.4
retrieving revision 1.4.152.1
diff -u -r1.4 -r1.4.152.1
--- source/filter.vcl/wmf/emfwr.hxx	5 Oct 2005 13:21:04 -0000	1.4
+++ source/filter.vcl/wmf/emfwr.hxx	22 Feb 2006 12:02:08 -0000	1.4.152.1
@@ -62,19 +62,19 @@
 	ULONG				mnRecordPos;
 	BOOL				mbRecordOpen;
 	BOOL				mbLineChanged;
-	ULONG				mnLineHandle;
+	sal_uInt32			mnLineHandle;
 	BOOL				mbFillChanged;
-	ULONG				mnFillHandle;
+	sal_uInt32			mnFillHandle;
 	BOOL				mbTextChanged;
-	ULONG				mnTextHandle;
+	sal_uInt32			mnTextHandle;
 
-	void				ImplBeginRecord( ULONG nType );
+	void				ImplBeginRecord( sal_uInt32 nType );
 	void				ImplEndRecord();
 						
 	ULONG				ImplAcquireHandle();
 	void				ImplReleaseHandle( ULONG nHandle );
 						
-	BOOL				ImplPrepareHandleSelect( ULONG& rHandle, ULONG nSelectType );
+	BOOL				ImplPrepareHandleSelect( sal_uInt32& rHandle, ULONG nSelectType );
 	void				ImplCheckLineAttr();
 	void				ImplCheckFillAttr();
 	void				ImplCheckTextAttr();
Index: source/filter.vcl/wmf/wmfwr.hxx
===================================================================
RCS file: /cvs/util/svtools/source/filter.vcl/wmf/wmfwr.hxx,v
retrieving revision 1.9
retrieving revision 1.9.152.1
diff -u -r1.9 -r1.9.152.1
--- source/filter.vcl/wmf/wmfwr.hxx	5 Oct 2005 13:21:42 -0000	1.9
+++ source/filter.vcl/wmf/wmfwr.hxx	22 Feb 2006 12:02:08 -0000	1.9.152.1
@@ -88,7 +88,7 @@
 	USHORT			nTargetDivisor;
 
 	ULONG nMetafileHeaderPos;
-	ULONG nMaxRecordSize; // in Worten
+	sal_uInt32 nMaxRecordSize; // in Worten
 	ULONG nActRecordPos;
 
 	// Aktuelle Attribute im Quell-Metafile:
@@ -145,7 +145,7 @@
 	void WriteRectangle(const Rectangle & rRect);
 	void WriteColor(const Color & rColor);
 
-	void WriteRecordHeader(ULONG nSizeWords, USHORT nType);
+	void WriteRecordHeader(sal_uInt32 nSizeWords, sal_uInt16 nType);
 		// nSizeWords ist die Groesse des gesammten Records in Anzahl Worte.
 		// Wenn nSizeWords unbekannt ist, dann 0 einsetzen (siehe UpdateRecordHeader()).
 
@@ -188,7 +188,7 @@
 	void WMFRecord_SetTextColor(const Color & rColor);
 	void WMFRecord_SetWindowExt(const Size & rSize);
 	void WMFRecord_SetWindowOrg(const Point & rPoint);
-	void WMFRecord_StretchDIB(const Point & rPoint, const Size & rSize, const Bitmap & rBitmap, ULONG nROP = 0UL );
+	void WMFRecord_StretchDIB(const Point & rPoint, const Size & rSize, const Bitmap & rBitmap, sal_uInt32 nROP = 0UL );
 	void WMFRecord_TextOut(const Point & rPoint, const String & rString);
 	void WMFRecord_EndOfFile();
 	void WMFRecord_IntersectClipRect( const Rectangle& rRect);
Index: source/items/rngitem.cxx
===================================================================
RCS file: /cvs/util/svtools/source/items/rngitem.cxx,v
retrieving revision 1.6
retrieving revision 1.6.176.1
diff -u -r1.6 -r1.6.176.1
--- source/items/rngitem.cxx	8 Sep 2005 16:00:38 -0000	1.6
+++ source/items/rngitem.cxx	22 Feb 2006 12:02:08 -0000	1.6.176.1
@@ -51,7 +51,7 @@
 #include "rngitem.hxx"
 #include "rngitem.cxx"
 
-#define NUMTYPE	ULONG
+#define NUMTYPE	sal_uInt32
 #define SfxXRangeItem SfxULongRangeItem
 #define SfxXRangesItem SfxULongRangesItem
 #include "rngitem.hxx"
Index: source/items/style.cxx
===================================================================
RCS file: /cvs/util/svtools/source/items/style.cxx,v
retrieving revision 1.10
retrieving revision 1.10.176.1
diff -u -r1.10 -r1.10.176.1
--- source/items/style.cxx	8 Sep 2005 16:01:12 -0000	1.10
+++ source/items/style.cxx	22 Feb 2006 12:02:08 -0000	1.10.176.1
@@ -840,7 +840,7 @@
 			XubString aName, aParent, aFollow;
 			String aHelpFile;
 			USHORT nFamily, nMask,nCount;
-			ULONG nHelpId;
+			sal_uInt32 nHelpId;
 			rStream.ReadByteString(aName, eEnc );
 			rStream.ReadByteString(aParent, eEnc );
 			rStream.ReadByteString(aFollow, eEnc );
@@ -933,7 +933,7 @@
 		XubString aName, aParent, aFollow;
 		String aHelpFile;
 		USHORT nFamily, nMask,nCount;
-		ULONG nHelpId;
+		sal_uInt32 nHelpId;
 		rStream.ReadByteString(aName, eEnc );
 		rStream.ReadByteString(aParent, eEnc );
 		rStream.ReadByteString(aFollow, eEnc );
@@ -1082,7 +1082,7 @@
 
 				// Globale Teile speichern
 				String aHelpFile;
-				ULONG nHelpId = p->GetHelpId( aHelpFile );
+				sal_uInt32 nHelpId = p->GetHelpId( aHelpFile );
 				USHORT nFamily = p->GetFamily();
 				String sFamily( (sal_Unicode)nFamily );
 
Index: source/items1/cintitem.cxx
===================================================================
RCS file: /cvs/util/svtools/source/items1/cintitem.cxx,v
retrieving revision 1.3
retrieving revision 1.3.176.1
diff -u -r1.3 -r1.3.176.1
--- source/items1/cintitem.cxx	8 Sep 2005 16:02:42 -0000	1.3
+++ source/items1/cintitem.cxx	22 Feb 2006 12:02:09 -0000	1.3.176.1
@@ -461,7 +461,7 @@
 	SfxPoolItem(nWhich)
 {
 	DBG_CTOR(CntUInt32Item, 0);
-	ULONG nTheValue = 0;
+	sal_uInt32 nTheValue = 0;
 	rStream >> nTheValue;
 	m_nValue = nTheValue;
 }
@@ -546,7 +546,7 @@
 SvStream & CntUInt32Item::Store(SvStream &rStream, USHORT) const
 {
 	DBG_CHKTHIS(CntUInt32Item, 0);
-	rStream << ULONG(m_nValue);
+	rStream << static_cast<sal_uInt32>(m_nValue);
 	return rStream;
 }
 
Index: source/items1/lckbitem.cxx
===================================================================
RCS file: /cvs/util/svtools/source/items1/lckbitem.cxx,v
retrieving revision 1.3
retrieving revision 1.3.176.1
diff -u -r1.3 -r1.3.176.1
--- source/items1/lckbitem.cxx	8 Sep 2005 16:06:55 -0000	1.3
+++ source/items1/lckbitem.cxx	22 Feb 2006 12:02:09 -0000	1.3.176.1
@@ -118,7 +118,7 @@
 
 SfxPoolItem* SfxLockBytesItem::Create( SvStream &rStream, USHORT nVersion ) const
 {
-	ULONG nSize = 0;
+	sal_uInt32 nSize = 0;
 	ULONG nActRead = 0;
 	sal_Char cTmpBuf[MAX_BUF];
 	SvMemoryStream aNewStream;
@@ -142,7 +142,7 @@
 SvStream& SfxLockBytesItem::Store(SvStream &rStream, USHORT nItemVersion ) const
 {
 	SvStream aLockBytesStream( _xVal );
-	ULONG nSize = aLockBytesStream.Seek( STREAM_SEEK_TO_END );
+	sal_uInt32 nSize = aLockBytesStream.Seek( STREAM_SEEK_TO_END );
 	aLockBytesStream.Seek( 0L );
 
 	rStream << nSize;
Index: source/items1/poolio.cxx
===================================================================
RCS file: /cvs/util/svtools/source/items1/poolio.cxx,v
retrieving revision 1.3
retrieving revision 1.3.176.1
diff -u -r1.3 -r1.3.176.1
--- source/items1/poolio.cxx	8 Sep 2005 16:08:16 -0000	1.3
+++ source/items1/poolio.cxx	22 Feb 2006 12:02:09 -0000	1.3.176.1
@@ -738,7 +738,7 @@
 		CHECK_FILEFORMAT( rStream, SFX_ITEMPOOL_TAG_STARTPOOL_4 );
 		rStream >> pImp->nMajorVer >> pImp->nMinorVer;
 	}
-	ULONG nAttribSize;
+	sal_uInt32 nAttribSize;
 	int bOwnPool = TRUE;
 	UniString aExternName;
 	if ( pImp->nMajorVer > 1 || pImp->nMinorVer >= 2 )
@@ -771,7 +771,7 @@
 	ULONG nStartPos = rStream.Tell();
 	rStream.SeekRel( nAttribSize );
 	CHECK_FILEFORMAT( rStream, SFX_ITEMPOOL_TAG_SIZES );
-	ULONG nSizeTableLen;
+	sal_uInt32 nSizeTableLen;
 	rStream >> nSizeTableLen;
 	sal_Char *pBuf = new sal_Char[nSizeTableLen];
 	rStream.Read( pBuf, nSizeTableLen );
@@ -783,7 +783,7 @@
 	{
 		// Version-Map finden (letztes ULONG der Size-Table gibt Pos an)
 		rStream.Seek( nEndOfSizes - sizeof(ULONG) );
-		ULONG nVersionMapPos;
+		sal_uInt32 nVersionMapPos;
 		rStream >> nVersionMapPos;
 		rStream.Seek( nVersionMapPos );
 
@@ -831,7 +831,7 @@
 		int bKnownItem = bOwnPool || IsWhich(nMappedWhich);
 
 		USHORT nRef, nCount, nVersion;
-		ULONG nAttrSize;
+		sal_uInt32 nAttrSize;
 		rStream >> nVersion >> nCount;
 
 		SfxPoolItemArray_Impl **ppArr = 0;
@@ -978,7 +978,8 @@
 		USHORT nMappedWhich = GetWhich(nSlot, FALSE);
 		int bKnownItem = bOwnPool || IsWhich(nMappedWhich);
 
-		ULONG nSize, nPos = nLastPos;
+		ULONG nPos = nLastPos;
+		sal_uInt32 nSize;
 		USHORT nVersion;
 		rStream >> nVersion;
 
@@ -1671,7 +1672,7 @@
 	{
 		// bDirekt bzw. nicht IsPoolable() => Item direkt laden
 		USHORT nVersion;
-		ULONG  nLen;
+		sal_uInt32 nLen;
 		rStream >> nVersion >> nLen;
 		ULONG nStart = rStream.Tell();
 
Index: source/misc/graphictools.cxx
===================================================================
RCS file: /cvs/util/svtools/source/misc/graphictools.cxx,v
retrieving revision 1.7
retrieving revision 1.7.178.1
diff -u -r1.7 -r1.7.178.1
--- source/misc/graphictools.cxx	8 Sep 2005 16:17:08 -0000	1.7
+++ source/misc/graphictools.cxx	22 Feb 2006 12:02:09 -0000	1.7.178.1
@@ -341,7 +341,7 @@
     rOStm << nTmp;
     rOStm << rClass.mfMiterLimit;
 
-    rOStm << (sal_Size)rClass.maDashArray.size();
+    rOStm << static_cast<sal_uInt32>(rClass.maDashArray.size());
     size_t i;
     for(i=0; i<rClass.maDashArray.size(); ++i)
         rOStm << rClass.maDashArray[i];
@@ -365,7 +365,7 @@
     rClass.maJoinType = SvtGraphicStroke::JoinType(nTmp);
     rIStm >> rClass.mfMiterLimit;
 
-    sal_Size nSize;
+    sal_uInt32 nSize;
     rIStm >> nSize;
     rClass.maDashArray.resize(nSize);
     size_t i;
Index: source/numbers/numhead.cxx
===================================================================
RCS file: /cvs/util/svtools/source/numbers/numhead.cxx,v
retrieving revision 1.5
retrieving revision 1.5.178.1
diff -u -r1.5 -r1.5.178.1
--- source/numbers/numhead.cxx	8 Sep 2005 16:34:04 -0000	1.5
+++ source/numbers/numhead.cxx	22 Feb 2006 12:02:10 -0000	1.5.178.1
@@ -119,7 +119,7 @@
 ImpSvNumMultipleReadHeader::ImpSvNumMultipleReadHeader(SvStream& rNewStream) :
 	rStream( rNewStream )
 {
-	ULONG nDataSize;
+	sal_uInt32 nDataSize;
 	rStream >> nDataSize;
 	ULONG nDataPos = rStream.Tell();
 	nEntryEnd = nDataPos;
@@ -131,7 +131,7 @@
 	{
 		DBG_ERROR("SV_NUMID_SIZES nicht gefunden");
 	}
-	ULONG nSizeTableLen;
+	sal_uInt32 nSizeTableLen;
 	rStream >> nSizeTableLen;
 	pBuf = new char[nSizeTableLen];
 	rStream.Read( pBuf, nSizeTableLen );
@@ -157,7 +157,7 @@
 // static
 void ImpSvNumMultipleReadHeader::Skip( SvStream& rStream )
 {
-	ULONG nDataSize;
+	sal_uInt32 nDataSize;
 	rStream >> nDataSize;
 	rStream.SeekRel( nDataSize );
 	USHORT nID;
@@ -166,7 +166,7 @@
 	{
 		DBG_ERROR("SV_NUMID_SIZES nicht gefunden");
 	}
-	ULONG nSizeTableLen;
+	sal_uInt32 nSizeTableLen;
 	rStream >> nSizeTableLen;
 	rStream.SeekRel( nSizeTableLen );
 }
@@ -186,7 +186,7 @@
 void ImpSvNumMultipleReadHeader::StartEntry()
 {
 	ULONG nPos = rStream.Tell();
-	ULONG nEntrySize;
+	sal_uInt32 nEntrySize;
 	(*pMemStream) >> nEntrySize;
 
 	nEntryEnd = nPos + nEntrySize;
@@ -227,7 +227,7 @@
 	ULONG nDataEnd = rStream.Tell();
 
 	rStream << (USHORT) SV_NUMID_SIZES;
-	rStream << aMemStream.Tell();
+	rStream << static_cast<sal_uInt32>(aMemStream.Tell());
 	rStream.Write( aMemStream.GetData(), aMemStream.Tell() );
 
 	if ( nDataEnd - nDataPos != nDataSize )					// Default getroffen?
@@ -245,7 +245,7 @@
 void ImpSvNumMultipleWriteHeader::EndEntry()
 {
 	ULONG nPos = rStream.Tell();
-	aMemStream << nPos - nEntryStart;
+	aMemStream << static_cast<sal_uInt32>(nPos - nEntryStart);
 }
 
 //#pragma SEG_FUNCDEF(numhead_0e)
Index: source/numbers/numhead.hxx
===================================================================
RCS file: /cvs/util/svtools/source/numbers/numhead.hxx,v
retrieving revision 1.2
retrieving revision 1.2.178.1
diff -u -r1.2 -r1.2.178.1
--- source/numbers/numhead.hxx	8 Sep 2005 16:34:20 -0000	1.2
+++ source/numbers/numhead.hxx	22 Feb 2006 12:02:10 -0000	1.2.178.1
@@ -100,7 +100,7 @@
 	SvStream&		rStream;
 	SvMemoryStream	aMemStream;
 	ULONG			nDataPos;
-	ULONG			nDataSize;
+	sal_uInt32		nDataSize;
 	ULONG			nEntryStart;
 
 public:
Index: source/numbers/zforlist.cxx
===================================================================
RCS file: /cvs/util/svtools/source/numbers/zforlist.cxx,v
retrieving revision 1.58
retrieving revision 1.58.84.1
diff -u -r1.58 -r1.58.84.1
--- source/numbers/zforlist.cxx	14 Dec 2005 15:01:33 -0000	1.58
+++ source/numbers/zforlist.cxx	22 Feb 2006 12:02:10 -0000	1.58.84.1
@@ -967,7 +967,7 @@
 				pEntry->GetNewStandardDefined() ||
 				(pTable->GetCurKey() % SV_COUNTRY_LANGUAGE_OFFSET == 0) )
 		{
-			rStream << pTable->GetCurKey()
+			rStream << static_cast<sal_uInt32>(pTable->GetCurKey())
 					<< (USHORT) LANGUAGE_SYSTEM
 					<< (USHORT) pEntry->GetLanguage();
 			pEntry->Save(rStream, aHdr);
Index: source/svhtml/parhtml.cxx
===================================================================
RCS file: /cvs/util/svtools/source/svhtml/parhtml.cxx,v
retrieving revision 1.8
retrieving revision 1.8.178.1
diff -u -r1.8 -r1.8.178.1
--- source/svhtml/parhtml.cxx	8 Sep 2005 16:48:16 -0000	1.8
+++ source/svhtml/parhtml.cxx	22 Feb 2006 12:00:18 -0000	1.8.178.1
@@ -165,7 +165,7 @@
 		"HTMLOption: unbekanntes Token" );
 }
 
-ULONG HTMLOption::GetNumber() const
+sal_uInt32 HTMLOption::GetNumber() const
 {
 	DBG_ASSERT( (nToken>=HTML_OPTION_NUMBER_START &&
 				 nToken<HTML_OPTION_NUMBER_END) ||
Index: source/uno/unoiface.cxx
===================================================================
RCS file: /cvs/util/svtools/source/uno/unoiface.cxx,v
retrieving revision 1.18
retrieving revision 1.18.178.1
diff -u -r1.18 -r1.18.178.1
--- source/uno/unoiface.cxx	8 Sep 2005 16:56:31 -0000	1.18
+++ source/uno/unoiface.cxx	22 Feb 2006 12:00:19 -0000	1.18.178.1
@@ -1723,7 +1723,7 @@
 {
 	::vos::OGuard aGuard( GetMutex() );
 
-	maImageConsumer.SetColorModel( BitCount, RGBAPal.getLength(), (const unsigned long*) RGBAPal.getConstArray(), RedMask, GreenMask, BlueMask, AlphaMask );
+	maImageConsumer.SetColorModel( BitCount, RGBAPal.getLength(), (const sal_uInt32*) RGBAPal.getConstArray(), RedMask, GreenMask, BlueMask, AlphaMask );
 }
 
 
@@ -1739,7 +1739,7 @@
 {
 	::vos::OGuard aGuard( GetMutex() );
 
-	maImageConsumer.SetPixelsByLongs( X, Y, Width, Height, (const unsigned long*) ProducerData.getConstArray(), Offset, Scansize );
+	maImageConsumer.SetPixelsByLongs( X, Y, Width, Height, (const sal_uInt32*) ProducerData.getConstArray(), Offset, Scansize );
 	ImplUpdateImage( sal_True );
 }
 

Index: source/filter.vcl/wmf/wmfwr.cxx
===================================================================
RCS file: /cvs/util/svtools/source/filter.vcl/wmf/wmfwr.cxx,v
retrieving revision 1.23
retrieving revision 1.23.150.1
diff -u -r1.23 -r1.23.150.1
--- source/filter.vcl/wmf/wmfwr.cxx	5 Oct 2005 13:21:22 -0000	1.23
+++ source/filter.vcl/wmf/wmfwr.cxx	22 Feb 2006 12:02:08 -0000	1.23.150.1
@@ -353,7 +353,7 @@
 }
 
 
-void WMFWriter::WriteRecordHeader(ULONG nSizeWords, USHORT nType)
+void WMFWriter::WriteRecordHeader(sal_uInt32 nSizeWords, sal_uInt16 nType)
 {
 	nActRecordPos=pWMF->Tell();
 	if (nSizeWords>nMaxRecordSize) nMaxRecordSize=nSizeWords;
@@ -363,7 +363,8 @@
 
 void WMFWriter::UpdateRecordHeader()
 {
-	ULONG nPos,nSize;
+	ULONG nPos;
+	sal_uInt32 nSize;
 
 	nPos=pWMF->Tell(); nSize=nPos-nActRecordPos;
 	if ((nSize & 1)!=0) {
@@ -879,7 +880,7 @@
 
 
 void WMFWriter::WMFRecord_StretchDIB( const Point & rPoint, const Size & rSize,
-									  const Bitmap & rBitmap, ULONG nROP )
+									  const Bitmap & rBitmap, sal_uInt32 nROP )
 {
 	ULONG nPosAnf,nPosEnd;
 
@@ -1708,20 +1709,21 @@
 	}
 
 	nMetafileHeaderPos=pWMF->Tell();
-	*pWMF << (USHORT)0x0001           // Typ: Datei
-		  << (USHORT)0x0009           // Headerlaenge in Worten
-		  << (USHORT)0x0300           // Version als BCD-Zahl
-		  << (ULONG) 0x00000000       // Dateilaenge (ohne 1. Header), wird spaeter durch UpdateHeader() berichtigt
-		  << (USHORT)MAXOBJECTHANDLES // Maximalezahl der gleichzeitigen Objekte
-		  << (ULONG) 0x00000000       // Maximale Record-laenge, wird spaeter durch UpdateHeader() berichtigt
-		  << (USHORT)0x0000;          // Reserved
+	*pWMF << (sal_uInt16)0x0001           // Typ: Datei
+		  << (sal_uInt16)0x0009           // Headerlaenge in Worten
+		  << (sal_uInt16)0x0300           // Version als BCD-Zahl
+		  << (sal_uInt32) 0x00000000  	  // Dateilaenge (ohne 1. Header), wird spaeter durch UpdateHeader() berichtigt
+		  << (sal_uInt16)MAXOBJECTHANDLES // Maximalezahl der gleichzeitigen Objekte
+		  << (sal_uInt32) 0x00000000  	  // Maximale Record-laenge, wird spaeter durch UpdateHeader() berichtigt
+		  << (sal_uInt16)0x0000;          // Reserved
 }
 
 // ------------------------------------------------------------------------
 
 void WMFWriter::UpdateHeader()
 {
-	ULONG nPos,nFileSize;
+	ULONG nPos;
+	sal_uInt32 nFileSize;
 
 	nPos=pWMF->Tell();                 // Endposition = Gesammtgroesse der Datei
 	nFileSize=nPos-nMetafileHeaderPos; // Groesse des 1. Headers abziehen